@@ -80,6 +80,13 @@ class NoMorePages(SearchException):
     pass
 
 
+class RequestThrottled(AmazonException):
+    """Exception for when Amazon has throttled a request, per:
+    http://docs.aws.amazon.com/AWSECommerceService/latest/DG/ErrorNumbers.html
+    """
+    pass
+
+
 class SimilartyLookupException(AmazonException):
     """Similarty Lookup Exception.
     """
@@ -189,6 +196,27 @@ class AmazonAPI(object):
                 region=self.region
             )
 
+    def lookup_bulk(self, ResponseGroup="Large", **kwargs):
+        """Lookup Amazon Products in bulk.
+
+        Returns all products matching requested ASINs, ignoring invalid
+        entries.
+
+        :return:
+            A list of  :class:`~.AmazonProduct` instances.
+        """
+        response = self.api.ItemLookup(ResponseGroup=ResponseGroup, **kwargs)
+        root = objectify.fromstring(response)
+        if not hasattr(root.Items, 'Item'):
+            return []
+        return list(
+            AmazonProduct(
+                item,
+                self.aws_associate_tag,
+                self,
+                region=self.region) for item in root.Items.Item
+        )
+
     def similarity_lookup(self, ResponseGroup="Large", **kwargs):
         """Similarty Lookup.
 
@@ -277,14 +305,12 @@ class AmazonAPI(object):
         if len(items) > 10:
             raise CartException("You can't add more than 10 items at once")
 
-        offer_id_key_template = 'Item.%s.OfferListingId'
-        quantity_key_template = 'Item.%s.Quantity'
-        i = 0
+        offer_id_key_template = 'Item.{0}.OfferListingId'
+        quantity_key_template = 'Item.{0}.Quantity'
 
-        for item in items:
-            i += 1
-            kwargs[offer_id_key_template % (i, )] = item['offer_id']
-            kwargs[quantity_key_template % (i, )] = item['quantity']
+        for i, item in enumerate(items):
+            kwargs[offer_id_key_template.format(i)] = item['offer_id']
+            kwargs[quantity_key_template.format(i)] = item['quantity']
 
         response = self.api.CartCreate(**kwargs)
         root = objectify.fromstring(response)
@@ -313,14 +339,12 @@ class AmazonAPI(object):
         if len(items) > 10:
             raise CartException("You can't add more than 10 items at once")
 
-        offer_id_key_template = 'Item.%s.OfferListingId'
-        quantity_key_template = 'Item.%s.Quantity'
-        i = 0
+        offer_id_key_template = 'Item.{0}.OfferListingId'
+        quantity_key_template = 'Item.{0}.Quantity'
 
-        for item in items:
-            i += 1
-            kwargs[offer_id_key_template % (i, )] = item['offer_id']
-            kwargs[quantity_key_template % (i, )] = item['quantity']
+        for i, item in enumerate(items):
+            kwargs[offer_id_key_template.format(i)] = item['offer_id']
+            kwargs[quantity_key_template.format(i)] = item['quantity']
 
         response = self.api.CartAdd(CartId=CartId, HMAC=HMAC, **kwargs)
         root = objectify.fromstring(response)
@@ -383,14 +407,12 @@ class AmazonAPI(object):
         if len(items) > 10:
             raise CartException("You can't add more than 10 items at once")
 
-        cart_item_id_key_template = 'Item.%s.CartItemId'
-        quantity_key_template = 'Item.%s.Quantity'
-        i = 0
+        cart_item_id_key_template = 'Item.{0}.CartItemId'
+        quantity_key_template = 'Item.{0}.Quantity'
 
-        for item in items:
-            i += 1
-            kwargs[cart_item_id_key_template % (i, )] = item['cart_item_id']
-            kwargs[quantity_key_template % (i, )] = item['quantity']
+        for i, item in enumerate(items):
+            kwargs[cart_item_id_key_template.format(i)] = item['cart_item_id']
+            kwargs[quantity_key_template.format(i)] = item['quantity']
 
         response = self.api.CartModify(CartId=CartId, HMAC=HMAC, **kwargs)
         root = objectify.fromstring(response)
@@ -553,6 +575,9 @@ class AmazonSearch(object):
             msg = root.Items.Request.Errors.Error.Message
             if code == 'AWS.ParameterOutOfRange':
                 raise NoMorePages(msg)
+            elif code == 'HTTP Error 503':
+                raise RequestThrottled(
+                    "Request Throttled Error: '{0}', '{1}'".format(code, msg))
             else:
                 raise SearchException(
                     "Amazon Search Error: '{0}', '{1}'".format(code, msg))
@@ -684,6 +709,16 @@ class AmazonProduct(LXMLWrapper):
         else:
             return None, None
 
+    @property
+    def offer_id(self):
+        """Offer ID
+
+        :return:
+            Offer ID (string).
+        """
+        return self._safe_get_element(
+            'Offers.Offer.OfferListing.OfferListingId')
+
     @property
     def asin(self):
         """ASIN (Amazon ID)
@@ -717,8 +752,8 @@ class AmazonProduct(LXMLWrapper):
     @property
     def author(self):
         """Author.
-
         Depricated, please use `authors`.
+
         :return:
             Author (string).
         """
@@ -906,6 +941,7 @@ class AmazonProduct(LXMLWrapper):
         """Customer Reviews.
 
         Get a iframe URL for customer reviews.
+
         :return:
             A tuple of: has_reviews (bool), reviews url (string)
         """
@@ -1041,6 +1077,7 @@ class AmazonProduct(LXMLWrapper):
         """Languages.
 
         Returns a set of languages in lower-case.
+
         :return:
             Returns a set of languages in lower-case (strings).
         """
@@ -1058,6 +1095,7 @@ class AmazonProduct(LXMLWrapper):
         """Features.
 
         Returns a list of feature descriptions.
+
         :return:
             Returns a list of 'ItemAttributes.Feature' elements (strings).
         """
@@ -1103,6 +1141,7 @@ class AmazonProduct(LXMLWrapper):
 
         Gets XML attributes of the product attribute. These usually contain
         details about the product attributes such as units.
+
         :param name:
             Attribute name (string)
         :return:
@@ -1132,6 +1171,7 @@ class AmazonProduct(LXMLWrapper):
         """Parent ASIN.
 
         Can be used to test if product has a parent.
+
         :return:
             Parent ASIN if product has a parent.
         """
@@ -1142,6 +1182,7 @@ class AmazonProduct(LXMLWrapper):
 
         Fetch parent product if it exists.
         Use `parent_asin` to check if a parent exist before fetching.
+
         :return:
             An instance of :class:`~.AmazonProduct` representing the
             parent product.
@@ -1168,10 +1209,10 @@ class AmazonProduct(LXMLWrapper):
     @property
     def images(self):
         """List of images for a response.
-
         When using lookup with RespnoseGroup 'Images', you'll get a
         list of images. Parse them so they are returned in an easily
         used list format.
+
         :return:
             A list of `ObjectifiedElement` images
         """
@@ -1182,6 +1223,41 @@ class AmazonProduct(LXMLWrapper):
             images = []
         return images
 
+    @property
+    def genre(self):
+        """Movie Genre.
+
+        :return:
+            The genre of a movie.
+        """
+        return self._safe_get_element_text('ItemAttributes.Genre')
+
+    @property
+    def actors(self):
+        """Movie Actors.
+
+        :return:
+            A list of actors names.
+        """
+        result = []
+        actors = self._safe_get_element('ItemAttributes.Actor') or []
+        for actor in actors:
+            result.append(actor.text)
+        return result
+
+    @property
+    def directors(self):
+        """Movie Directors.
+
+        :return:
+            A list of directors for a movie.
+        """
+        result = []
+        directors = self._safe_get_element('ItemAttributes.Director') or []
+        for director in directors:
+            result.append(director.text)
+        return result
+
 
 class AmazonCart(LXMLWrapper):
     """Wrapper around Amazon shopping cart.
@@ -1233,7 +1309,7 @@ class AmazonCart(LXMLWrapper):
         for item in self:
             if item.cart_item_id == cart_item_id:
                 return item
-        raise KeyError('no item found with CartItemId: %s' % (cart_item_id,))
+        raise KeyError('no item found with CartItemId: {0}'.format(cart_item_id,))
 
 
 class AmazonCartItem(LXMLWrapper):
